<?php
// Version: 1.1.5; index

/*	This template is, perhaps, the most important template in the theme.  It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below.  It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';
	
        /* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '1.1.5';
	
	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = false;

	/* Use plain buttons - as oppossed to text buttons? */
	$settings['use_buttons'] = true;

	/* Show sticky and lock status seperate from topic icons? */
	$settings['seperate_sticky_lock'] = false;
}

// The main sub template above the content.
function template_main_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '><head>
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title'], '" />', empty($context['robot_no_index']) ? '' : '
	<meta name="robots" content="noindex" />', '
	<meta name="keywords" content="PHP, MySQL, bulletin, board, free, open, source, smf, simple, machines, forum" />
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/script.js?115"></script>
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';
		var smf_charset = "', $context['character_set'], '";
	// ]]></script>
	<title>', $context['page_title'], '</title>';

	// The stylesheet files
	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style.css?115" />
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/print.css?115" media="print" />';

	/* Internet Explorer 4/5 and Opera 6 just don't do font sizes properly. (they are big...)
		Thus, in Internet Explorer 4, 5, and Opera 6 this will show fonts one size smaller than usual.
		Note that this is affected by whether IE 6 is in standards compliance mode.. if not, it will also be big.
		Standards compliance mode happens when you use xhtml... */
	if ($context['browser']['needs_size_fix'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/fonts-compat.css" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" target="_blank" />
	<link rel="search" href="' . $scripturl . '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';
	
	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']))
	echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name'], ' - RSS" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';
	
        // If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="' . $scripturl . '?board=' . $context['current_board'] . '.0" />';

	// We'll have to use the cookie to remember the header...
	if ($context['user']['is_guest'])
	{
		$options['collapse_header'] = !empty($_COOKIE['upshrink']);
		$options['collapse_header_ic'] = !empty($_COOKIE['upshrinkIC']);
	}

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'], '

	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var current_header = ', empty($options['collapse_header']) ? 'false' : 'true', ';

		function shrinkHeader(mode)
		{';

	// Guests don't have theme options!!
	if ($context['user']['is_guest'])
		echo '
			document.cookie = "upshrink=" + (mode ? 1 : 0);';
	else
		echo '
		        smf_setThemeOption("collapse_header", mode ? 1 : 0, null, "', $context['session_id'], '");';

	echo '
			document.getElementById("upshrink").src = smf_images_url + (mode ? "/upshrink2.gif" : "/upshrink.gif");

			document.getElementById("upshrinkHeader").style.display = mode ? "none" : "";

			current_header = mode;
		}
	// ]]></script>
</head>
<body>';
        // Here is the main table that will make the width of the forum maller than normal
        echo '
        <table class="maintable" align="center" border="0" cellpadding="0" cellspacing="0" width="';
        
        //The width definer
        
        if (!empty($settings['forum_width']))
		echo '100%';
        else
                echo '760';

        echo'
        ">
<tbody><tr>
	<td align="center" valign="top"><a name="top"></a>
        
        <table style="background: #525e6e; height: 69px;" border="0" cellpadding="0" cellspacing="0" width="100%">
	<tbody><tr>
		<td align="left" style="background: url(', $settings['images_url'], '/hdr_bg.gif); height: 69px;" width="69"><img src="', $settings['images_url'], '/hdr_left.gif" alt="" border="0" style="height: 69px;" width="69" /></td>
		<td style="background: url(', $settings['images_url'], '/hdr_bg.gif);" height="69" width="100%"><table border="0" cellpadding="0" cellspacing="0" width="100%">
		<tbody><tr>
			<td align="center" height="43" valign="middle" width="100%"><a href="', $scripturl, '">';
                        
        // This part is the logo and forum name.  You should be able to change this to whatever you want...

        if (empty($settings['header_logo_url']))
		echo '
					<img src="', $settings['images_url'], '/smflogo.gif" border="0" alt="', $context['forum_name'], '" />';
	else
		echo '
					<img src="', $settings['header_logo_url'], '" alt="', $context['forum_name'], '" border="0" />';

                echo '
                </a></td>
		</tr>
		<tr>
			<td align="center" height="23" nowrap="nowrap" valign="bottom" width="100%"><table border="0" cellpadding="0" cellspacing="0">
			<tbody><tr>', template_menu(), '
			</tr></tbody></table></td>
                        </tr></tbody></table></td>
		<td align="right" style="background: url(', $settings['images_url'], '/hdr_bg.gif);" height="69" width="69"><img src="', $settings['images_url'], '/hdr_right.gif" alt="" border="0" height="69" width="69" /></td>
</tr>
</tbody></table>';

	// The main content should go here.  A table is used because IE 6 just can't handle a div.
	echo '
	<table width="100%" cellpadding="10" cellspacing="0" border="0"><tr>
		<td id="bodyarea" align="left">';
}

function template_main_below()
{
	global $context, $settings, $options, $scripturl, $txt;

	// Show the "Powered by" and "Valid" logos, as well as the copyright.  Remember, the copyright must be somewhere!
	echo '
                <hr />
                
                <div style="text-align: center; padding-bottom: 1ex; width: 100%;">
		<table cellspacing="0" cellpadding="0" border="0" align="center" width="100%">
			<tr>
				<td width="28%" valign="middle" align="center">
                                    <a href="http://www.php.net/" target="_blank"><img id="powered-php" src="', $settings['images_url'], '/powered-php.gif" alt="', $txt['powered_by_php'], '" width="54" height="20" style="margin: 5px 16px;" border="0"/></a>
				</td>
				<td valign="middle" align="center" style="white-space: nowrap;">
				', theme_copyright(), '
				</td>
				<td width="28%" valign="middle" align="center">
                                    <a href="http://www.mysql.com/" target="_blank"><img id="powered-mysql" src="', $settings['images_url'], '/powered-mysql.gif" alt="', $txt['powered_by_mysql'], '" width="54" height="20" style="margin: 5px 16px;" border="0"/></a>
				</td>
			</tr></table>';

	// Show the load time?
	if ($context['show_load_time'])
		echo '
                <span class="smalltext">', $txt['smf301'], $context['load_time'], $txt['smf302'], $context['load_queries'], $txt['smf302b'], '</span>';
	echo '
                </div>
';

	echo '
        </td>
        </tr>
        </table>
        </td>
        </tr>
        <tr>
	<td align="center" style="background: url(', $settings['images_url'], '/footer_bg.gif);" height="25" valign="middle"><span class="copyright2">Eos theme by <a href="http://www.phpbbstyles.com/" target="_blank">CyberAlien</a> | Ported to SMF by <a href="http://www.erenyasarkurt.com/" target="_blank">forsakenlad</a></span></td>
        </tr>
        </tbody>
        </table>
	</body>
</html>';
}

// Show a linktree.  This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree()
{
	global $context, $settings, $options;

	// Folder style or inline?  Inline has a smaller font.
	echo '<span class="nav"', $settings['linktree_inline'] ? ' style="font-size: smaller;"' : '', '>';

	// Each tree item has a URL and name.  Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Show the link, including a URL if it should have one.
		echo '<b>', $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '" class="nav">' . $tree['name'] . '</a>' : $tree['name'], '</b>';

		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1)
			echo ' &nbsp;->&nbsp; ';
	}

	echo '</span>';
}

// Show the menu up top.  Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

	// Show the [home] and [help] buttons.
	echo '
				<td align="center" valign="bottom"><a href="', $scripturl, '">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/home.gif" alt="' . $txt[103] . '" style="margin: 2px 0;" border="0" />' : $txt[103]), '</a></td>
				<td align="center" valign="bottom"><a href="', $scripturl, '?action=help">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/help.gif" alt="' . $txt[119] . '" style="margin: 2px 0;" border="0" />' : $txt[119]), '</a></td>';

	// How about the [search] button?
	if ($context['allow_search'])
		echo '
				<td align="center" valign="bottom"><a href="', $scripturl, '?action=search">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/search.gif" alt="' . $txt[182] . '" style="margin: 2px 0;" border="0" />' : $txt[182]), '</a></td>';

        // The Memberlist Button
                echo '
				<td align="center" valign="bottom"><a href="', $scripturl, '?action=mlist"><img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/memberlist.gif" style="margin: 2px 0" border="0" alt="' . $txt[331] . '" /></a></td>';

        // Is the user allowed to administrate at all? ([admin])
	if ($context['allow_admin'])
		echo '
				<td align="center" valign="bottom"><a href="', $scripturl, '?action=admin">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/admin.gif" alt="' . $txt[2] . '" style="margin: 2px 0;" border="0" />' : $txt[2]), '</a></td>';

	// Edit Profile... [profile]
	if ($context['allow_edit_profile'])
		echo '
				<td align="center" valign="bottom"><a href="', $scripturl, '?action=profile">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/profile.gif" alt="' . $txt[79] . '" style="margin: 2px 0;" border="0" />' : $txt[467]), '</a></td>';

	// The [calendar]!
	if ($context['allow_calendar'])
		echo '
				<td align="center" valign="bottom"><a href="', $scripturl, '?action=calendar">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/calendar.gif" alt="' . $txt['calendar24'] . '" style="margin: 2px 0;" border="0" />' : $txt['calendar24']), '</a></td>';

	// If the user is a guest, show [login] and [register] buttons.
	if ($context['user']['is_guest'])
	{
		echo '
				<td align="center" valign="bottom"><a href="', $scripturl, '?action=login">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/login.gif" alt="' . $txt[34] . '" style="margin: 2px 0;" border="0" />' : $txt[34]), '</a></td>
				<td align="center" valign="bottom"><a href="', $scripturl, '?action=register">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/register.gif" alt="' . $txt[97] . '" style="margin: 2px 0;" border="0" />' : $txt[97]), '</a></td>';
	}
	// Otherwise, they might want to [logout]...
	else
		echo '
				<td align="center" valign="bottom"><a href="', $scripturl, '?action=pm"><img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/pm.gif" style="margin: 2px 0" border="0" alt="' . $txt['pm_short'] . '" /></a></td>
                                <td align="center" valign="bottom"><a href="', $scripturl, '?action=logout;sesc=', $context['session_id'], '">', ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/logout.gif" alt="' . $txt[108] . '" style="margin: 2px 0;" border="0" />' : $txt[108]), '</a></td>';
}

// Generate a strip of buttons, out of buttons.
function template_button_strip($button_strip, $direction = 'top', $force_reset = false, $custom_td = '')
{
   global $settings, $buttons, $context, $txt, $scripturl;

   if (empty($button_strip))
      return '';

   // Create the buttons...
   foreach ($button_strip as $key => $value)
   {
      if (isset($value['test']) && empty($context[$value['test']]))
      {
         unset($button_strip[$key]);
         continue;
      }
      elseif (!isset($buttons[$key]) || $force_reset)
         $buttons[$key] = '<a href="' . $value['url'] . '" ' .( isset($value['custom']) ? $value['custom'] : '') . '>' . ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . ($value['lang'] ? $context['user']['language'] . '/' : '') . $value['image'] . '" alt="' . $txt[$value['text']] . '" border="0" />' : $txt[$value['text']]) . '</a>';

      $button_strip[$key] = $buttons[$key];
   }

   echo '
      <td ', $custom_td, '>', implode($context['menu_separator'], $button_strip) , '</td>';
}

?>
